# HW1
This package is for moving the main function to a library, so the key is no longer exposed. Then, you replace the main function with the name of the library you have created.
### Installtion
```
$ pip install Hwk1
```

